@@ -19,7 +19,7 @@ cellStats <- function(raster, stat='mean', ...) {
 		}
 	}
 	if (class(stat) != 'character') {
-		if (dataContent(raster) == 'all') { n <- 1 } else {n <- 2}
+		if ( inMemory(raster) ) { n <- 1 } else {n <- 2}
 		if (canProcessInMemory(raster, n)) {
 			d <- na.omit(getValues(raster))
 			return( stat(d) )
