@@ -13,13 +13,14 @@ if (!isGeneric("plotRGB")) {
 setMethod("plotRGB", signature(x='RasterStackBrick'), 
 function(x, r=1, g=2, b=3, scale=255, maxpixels=500000, extent=NULL, interpolate=FALSE, axes=TRUE, xlab='', ylab='', asp, ...) { 
 	
-	if (!axes) par(plt=c(0,1,0,1))
-	
 	# rasterImage is new in R 2.11
-	v <- version
-	major <- as.numeric( v$major )
-	minor <- as.numeric( v$minor )
-	if (major < 2 | (major == 2 & minor < 11)) stop('You need R version 2.11 or higher to use this function')
+	if (! exists("rasterImage") ) {
+		stop('You need R version 2.11 or higher to use this function')
+	}
+	
+	.warnIfSDI()
+	
+	if (!axes) par(plt=c(0,1,0,1))
 
  	if (missing(asp)) {
 		if (.couldBeLonLat(x)) {
