@@ -148,7 +148,12 @@
 			result <- as.logical(result)
 		}
 		
+ 
+ 	} else if (object@file@driver == 'netcdf') {
+		result <- .readRowsBrickNetCDF(object, startrow, nrows, startcol, ncols)
+	
  #use GDAL  			
+ 
 	} else {
 		result <- matrix(nrow=ncols*nrows, ncol=nlayers(object))
 		offs <- c((startrow-1), (startcol-1)) 
@@ -162,23 +167,24 @@
 		result[result == object@file@nodatavalue] <- NA 					
 	}
 	
-	firstcell <- cellFromRowCol(object, startrow, 1)
-	lastcell <- cellFromRowCol(object, (startrow+nrows-1), object@ncols)
-	object@data@indices <- c(firstcell, lastcell)
-	if (all(object@data@indices == c(1, ncell(object)))) {
-		object@data@content <- 'all' 
-	} else if (startcol==1 & ncols==object@ncols) {
-		if (nrows==1) {
-			object@data@content <- 'row' 
-		} else {	
-			object@data@content <- 'rows' 
-		}
-	} else {
-		object@data@content <- 'block' 
-	}
+#	firstcell <- cellFromRowCol(object, startrow, 1)
+#	lastcell <- cellFromRowCol(object, (startrow+nrows-1), object@ncols)
+#	object@data@indices <- c(firstcell, lastcell)
+#	if (all(object@data@indices == c(1, ncell(object)))) {
+#		object@data@content <- 'all' 
+#	} else if (startcol==1 & ncols==object@ncols) {
+#		if (nrows==1) {
+#			object@data@content <- 'row' 
+#		} else {	
+#			object@data@content <- 'rows' 
+#		}
+#	} else {
+#		object@data@content <- 'block' 
+#	}
 	colnames(result) <- layerNames(object)
-	object@data@values <- result
-	return(object)
+#	object@data@values <- result
+#	return(object)
+	return(result)
 }
 
 
